@@ -49,7 +49,7 @@ from .partition import FusionPartition, NotEnoughDataToPartitionError, Partition
 
 
 class NoPointsToPlot(Exception):
-    pass
+    """Specific NoPointsToPlot Exception Class creation"""
 
 
 def compute_stats_array(
@@ -123,31 +123,48 @@ def compute_stats_array(
         geo_ref=False,
     )
     # save results
-    with open(final_json_file, "w") as outfile:
+    with open(final_json_file, "w", encoding="utf8") as outfile:
         json.dump(cfg, outfile, indent=2)
 
 
 def gaus(x, a, x_zero, sigma):
+    """Gauss math function"""
     return a * np.exp(-((x - x_zero) ** 2) / (2 * sigma ** 2))
 
 
 def round_up(x, y):
+    """Round up math function"""
     return int(math.ceil((x / float(y)))) * y
 
 
-def get_nonan_mask(array, nan_value):
+def get_nonan_mask(array, no_data_value=None):
+    """
+    Get no data and nan mask value
+
+    :param array: input array to get the mask from
+    :no_data_value: no data value considered. Default: None
+    :return: nan and no_data_value if exists mask on array.
+    """
+    if no_data_value is None:
+        return np.apply_along_axis(lambda x: (~np.isnan(x)), 0, array)
+    # else no_data_value exists
     return np.apply_along_axis(
-        lambda x: (~np.isnan(x)) * (x != nan_value), 0, array
+        lambda x: (~np.isnan(x)) * (x != no_data_value), 0, array
     )
 
 
 def get_outliers_free_mask(array, no_data_value=None):
     """
-    Get outliers free mask
+    Get outliers free mask (array of True where value is no outlier) with
+    values outside (mu + 3 sigma) and (mu - 3 sigma).
+    Nan and no_data_value are not considered in mu and sigma computation.
+
+    :param array: input array to compute outliers mask
+    :param no_data_value: value of no data to consider. Default(None)
+    :return: outliers free mask (array of True where value is no outlier)
     """
     # pylint: disable=singleton-comparison
-    if no_data_value:
-        no_data_free_mask = get_nonan_mask(array, no_data_value)
+    no_data_free_mask = get_nonan_mask(array, no_data_value)
     array_without_nan = array[np.where(no_data_free_mask == True)]  # noqa: E712
     mu = np.mean(array_without_nan)
     sigma = np.std(array_without_nan)
@@ -462,24 +479,25 @@ def dem_diff_plot(dem_diff, title="", plot_file="dem_diff.png", display=False):
     :param display: boolean, set to True if display is on,
         otherwise the plot is saved to plot_file location
     """
-
-    #
-    # Plot initialization
-    #
-    # -> import what is necessary for plot purpose
-
-    mpl.rc("font", size=6)
-
-    #
-    # Plot
-    #
-    mpl_pyplot.figure(1, figsize=(7.0, 8.0))
-    mpl_pyplot.title(title)
+    # Init mu and sigma from data to focus on little values
     mu = np.nanmean(dem_diff["im"].data)
     sigma = np.nanstd(dem_diff["im"].data)
-    mpl_pyplot.imshow(dem_diff["im"].data, vmin=mu - sigma, vmax=mu + sigma)
-    color_bar = mpl_pyplot.colorbar()
-    color_bar.set_label("Elevation differences (m)")
+
+    # Plot
+    fig, fig_ax = mpl_pyplot.subplots(figsize=(7.0, 8.0))
+    fig_ax.set_title(title, fontsize="large")
+    im1 = fig_ax.imshow(
+        dem_diff["im"].data, cmap="terrain", vmin=mu - sigma, vmax=mu + sigma
+    )
+    fig.colorbar(im1, label="Elevation differences (m)")
+    fig.text(
+        0.15,
+        0.15,
+        "Image diff view: [Min, Max]=[{:.2f}, {:.2f}]".format(
+            mu - sigma, mu + sigma
+        ),
+        fontsize="medium",
+    )
 
     #
     # Show or Save
@@ -491,6 +509,85 @@ def dem_diff_plot(dem_diff, title="", plot_file="dem_diff.png", display=False):
     mpl_pyplot.close()
 
 
+def dem_diff_cdf_plot(
+    dem_diff,
+    title="",
+    plot_file="dem_diff_cdf.png",
+    bin_step=0.1,
+    display=False,
+):
+    """
+    Simple img values absolute cdf view truncated by max_diff
+
+    :param dem_diff: xarray Dataset,
+    :param title: string, plot title
+    :param plot_file: path and name for the saved plot
+        (used when display if False)
+    :param bin_step: bin size
+    :param display: boolean, set to True if display is on,
+        otherwise the plot is saved to plot_file location
+    """
+    # Get plot_file file base
+    plot_file_base = os.path.splitext(plot_file)[0]
+
+    # Generate absolute values array
+    abs_dem_diff = np.abs(dem_diff["im"].data)
+
+    # Get max diff from data
+    max_diff = np.nanmax(abs_dem_diff)
+
+    # Count nb nan
+    nb_nans = np.sum(np.isnan(abs_dem_diff))
+    nb_pixels = abs_dem_diff.shape[0] * abs_dem_diff.shape[1]
+
+    # Get bins number for histogram
+    nb_bins = int(max_diff / bin_step)
+
+    # getting data of the histogram
+    hist, bins_count = np.histogram(
+        abs_dem_diff, bins=nb_bins, range=(0, max_diff), density=True
+    )
+
+    # Normalized Probability Density Function of the histogram
+    pdf = hist / sum(hist)
+
+    # Generate Cumulative Probability Function
+    cdf = np.cumsum(pdf)
+
+    # Save cdf in csv in same base file name.
+    with open(
+        plot_file_base + ".csv", "w", newline="", encoding="utf8"
+    ) as csv_file:
+        writer = csv.writer(csv_file, delimiter=",")
+        writer.writerow(["Bins", "CDF values"])
+        writer.writerows(zip(bins_count, cdf))
+
+    # Plot
+    fig, fig_ax = mpl_pyplot.subplots()
+    fig_ax.set_title(title, fontsize="large")
+    fig_ax.plot(bins_count[1:], cdf, label="CDF")
+
+    # tidy up the figure and add axes titles
+    fig_ax.set_xlabel(
+        "Full absolute elevation differences (m) "
+        "\nmax_diff={} nb_bins={}"
+        "\nnb_pixels={} nb_nans={}".format(
+            max_diff, nb_bins, nb_pixels, nb_nans
+        ),
+        fontsize="medium",
+    )
+    fig_ax.set_ylabel("Cumulative Probability [0,1]", fontsize="medium")
+    fig_ax.set_ylim(0, 1.05)
+    fig_ax.grid(True)
+
+    # Show or Save
+    if display is False:
+        fig.savefig(plot_file, dpi=100, bbox_inches="tight")
+    else:
+        fig.show()
+    mpl_pyplot.close()
+
+
 def plot_histograms(  # noqa: C901
     input_array,
     bin_step=0.1,
@@ -529,7 +626,7 @@ def plot_histograms(  # noqa: C901
         (as numpy files) are to be saved
     :param save_prefix: prefix to the histogram files saved by this method
     :param display: set to False to save plot instead of actually plotting them
-    :param plot_real_hist: plot or save (see display param) real histrograms
+    :param plot_real_hist: plot or save (see display param) real histograms
     :return: list saved files
     """
     # pylint: disable=singleton-comparison
@@ -597,10 +694,10 @@ def plot_histograms(  # noqa: C901
             # -> restricts to input data
             if to_keep_mask is not None:
                 sets[set_idx] = sets[set_idx] * to_keep_mask
-            print(
-                "}}}}}}}}}}}}}}}}}}}}}}}}}}}}}} plot_histograms() : ",
-                np.where(sets[set_idx] == True),  # noqa: E712
-            )
+            # print(
+            #     "}}}}}}}}}}}}}}}}}}}}}}}}}}}}}} plot_histograms() : ",
+            #     np.where(sets[set_idx] == True),  # noqa: E712
+            # )
             data.append(
                 input_array[np.where(sets[set_idx] == True)]  # noqa: E712
             )
@@ -778,7 +875,7 @@ def save_results(
     :param stats_list: all the stats to save (one element per label)
     :param labels_plotted: list of labels plotted
     :param plot_files: list of plot files associdated to the labels_plotted
-    :param plot_colors: list of plot colors associdated to the labels_plotted
+    :param plot_colors: list of plot colors associated to the labels_plotted
     :param to_csv: boolean, set to True to save to csv format as well
         (default False)
     :return:
@@ -809,7 +906,7 @@ def save_results(
                     )
                     raise
 
-    with open(output_json_file, "w") as outfile:
+    with open(output_json_file, "w", encoding="utf8") as outfile:
         json.dump(results, outfile, indent=4)
 
     if to_csv:
@@ -835,7 +932,7 @@ def save_results(
             csv_results[key]["NMAD"] = results[key]["nmad"]
             csv_results[key]["90 percentile"] = results[key]["90p"]
         # - writes the results down as csv format
-        with open(csv_filename, "w") as csvfile:
+        with open(csv_filename, "w", encoding="utf8") as csvfile:
             fieldnames = list(csv_results["0"].keys())
             writer = csv.DictWriter(
                 csvfile, fieldnames=fieldnames, quoting=csv.QUOTE_NONNUMERIC
@@ -988,9 +1085,10 @@ def alti_diff_stats(
     """
 
     def get_title(cfg):
+        """Create title for alti_diff_stats"""
         if geo_ref:
             # Set future plot title with bias and % of nan values as part of it
-            title = ["MNT quality performance"]
+            title = ["DEM quality performance"]
             dx = cfg["plani_results"]["dx"]
             dy = cfg["plani_results"]["dy"]
             biases = {
@@ -1038,6 +1136,9 @@ def alti_diff_stats(
         return title
 
     def get_thresholds_in_meters(cfg):
+        """
+        Create list of threshold in meters.
+        """
         # If required, get list of altitude thresholds and adjust the unit
         list_threshold_m = None
         if cfg["stats_opts"]["elevation_thresholds"]["list"]:
@@ -1155,7 +1256,6 @@ def save_as_graphs_and_tables(
         # Create plots for the actual mode and for all sets
         #
         # -> we are then ready to do some plots !
-
         if geo_ref:
             try:
                 plot_files, labels, colors = plot_histograms(
@@ -1272,7 +1372,6 @@ def wave_detection(cfg, dh):
     :return:
 
     """
-
     # Compute mean dh row and mean dh col
     # -> then compute min between dh mean row (col) vector and dh rows (cols)
     res = {
